# Changelog

<!--next-version-placeholder-->

## v0.3.2 (2022-11-22)
### Fix
* **ci:** Enable upload_to_pypi ([`7804904`](https://github.com/vincentullmann/test_semantic_version/commit/780490470e3f3816a7083fa95e239cfca691de15))

## v0.3.1 (2022-11-22)
### Fix
* **ci:** Fix build command ([`6c4684f`](https://github.com/vincentullmann/test_semantic_version/commit/6c4684f7370d7bc707f0219e5c1a80aa57f2ffcd))

## v0.3.0 (2022-11-22)
### Feature
* **deploy:** Upload release via flit ([`dc20f9a`](https://github.com/vincentullmann/test_semantic_version/commit/dc20f9aafcb54e25cf5bbec073889208d59ab033))

### Fix
* **ci:** Fix version_variable and pypi token ([`c59c021`](https://github.com/vincentullmann/test_semantic_version/commit/c59c021607103e3603345a209bce0d5c40263a5a))

## v0.2.0 (2022-11-22)
### Feature
* **ci:** Add github workflow ([`cb67fbf`](https://github.com/vincentullmann/test_semantic_version/commit/cb67fbffe6d3bfb47998c5bd5ea220fda8bfbcd2))

### Fix
* **deploy:** Disable build command and upload ([`66a76fd`](https://github.com/vincentullmann/test_semantic_version/commit/66a76fdcc7a69afd6a263e24cdbf95d1c86255fc))

## v0.1.2 (2022-11-22)
### Fix
* Add setup.py ([`4fb6127`](https://github.com/vincentullmann/test_semantic_version/commit/4fb612759b37b6e98b198b70c56593b8f5f1f65a))

## v0.1.1 (2022-11-22)
### Fix
* **deploy:** Disable pypi publish ([`6052e5b`](https://github.com/vincentullmann/test_semantic_version/commit/6052e5bb175e97d9692e3b877df6bd5df29d8749))

## v0.1.0 (2022-11-22)
### Feature
* **init:** Init version number ([`a253aa0`](https://github.com/vincentullmann/test_semantic_version/commit/a253aa0d2e8dcacddcbbd4a6423f80e9b722b60a))
